@@ -1,17 +1,13 @@
-# coding=utf-8
+# -*- coding: utf-8 -*-
 # /usr/bin/env python
 
 '''
 Author: wenqiangw
-Email: wenqiangw@opera.com
-Date: 2020-04-23 14:45
+Email: wqwangchn@163.com
+Date: 2021/10/26 10:53
 Desc:
-    等频分箱 & 等距分箱
-    >>> frequence_blocks(x=[1,2,3,4,5,6,3],box_num=3)
-    [-inf, 2.0, 4.5, inf]
-    >>> distince_blocks(x=[1,2,3,4,5,6,3],box_num=5)
-    [-inf, 2.0, 3.0, 4.0, 5.0, inf]
 '''
+
 import numpy as np
 
 def frequence_blocks(x, box_num=10):
@@ -25,6 +21,9 @@ def frequence_blocks(x, box_num=10):
     len_clocks = int(min(len(x),box_num))
     ind = np.linspace(0, len(x)-1, len_clocks).astype(int)
     tb=np.array(x)[ind]
+    tb = np.unique(tb)
+    if len(tb)<2:
+        return [-np.inf,np.inf]
     blocks = np.concatenate([[-np.inf],
                             0.5 * (tb[1:] + tb[:-1]),
                             [np.inf]])
@@ -37,14 +36,15 @@ def distince_blocks(x, box_num=5):
     :param bins: 分箱数量
     :return: 箱边界
     '''
-    if box_num<1:
-        return [-np.inf,np.inf]
     blocks = np.linspace(min(x), max(x), box_num+1)
+    blocks = np.unique(blocks)
+    if len(blocks)<2:
+        return [-np.inf,np.inf]
     blocks[0] = -np.inf
     blocks[-1] = np.inf
     return blocks.tolist()
 
 if __name__ == '__main__':
-    aa = frequence_blocks(x=[1, 2, 3, 4, 5, 6, 3], box_num=3)
-    bb = distince_blocks(x=[1, 2, 3, 4, 5, 6, 3], box_num=5)
+    aa = frequence_blocks(x=[1, 2, 2, 3, 2, 6, 3], box_num=10)
+    bb = distince_blocks(x=[1, 2, 2, 3, 2, 6, 3], box_num=2)
     print(aa,bb)
\ No newline at end of file
