@@ -35,7 +35,7 @@ def get_X_y(data_type):
     return X, y
 
 def test_logit(X,y):
-    lr  =  mpmr.Regression(X,y,measure='roc_auc',iter_num=20, max_related_level=2,observation_model='all')
+    lr  =  mpmr.Regression(X,y,measure='roc_auc',iter_num=20, max_related_level=2,observation_model='all',ignore_var=['informative_3'])
     in_vars,dr = lr.fit()
     return in_vars,dr
 
